@@ -3,7 +3,8 @@ Copyright (c) 2012-2013, Agora Games, LLC All rights reserved.
 
 https://github.com/agoragames/kairos/blob/master/LICENSE.txt
 '''
-__version__ = "0.6.2"
+from __future__ import absolute_import
+__version__ = "0.6.3"
 
-from timeseries import Timeseries
-from exceptions import *
+from .timeseries import Timeseries
+from .exceptions import *
